@@ -4,13 +4,13 @@ import sys
 import unittest
 
 from nose2 import events, loader, plugins, runner, session, util
+from nose2._toml import TOML_ENABLED
 
 log = logging.getLogger(__name__)
 __unittest = True
 
 
 class PluggableTestProgram(unittest.TestProgram):
-
     """TestProgram that enables plugins.
 
     Accepts the same parameters as :class:`unittest.TestProgram`,
@@ -84,7 +84,7 @@ class PluggableTestProgram(unittest.TestProgram):
         self.extraHooks = hooks
         self.defaultPlugins.extend(plugins)
         self.excludePlugins.extend(exclude)
-        super(PluggableTestProgram, self).__init__(**kw)
+        super().__init__(**kw)
 
     def parseArgs(self, argv):
         """Parse command line args
@@ -112,7 +112,7 @@ class PluggableTestProgram(unittest.TestProgram):
         self.argparse.add_argument("testNames", nargs="*")
         # add help arg now so -h will also print plugin opts
         self.argparse.add_argument(
-            "-h", "--help", action="help", help=("Show this help message and exit")
+            "-h", "--help", action="help", help="Show this help message and exit"
         )
         args, argv = self.argparse.parse_known_args(argv)
         if argv:
@@ -145,8 +145,10 @@ class PluggableTestProgram(unittest.TestProgram):
             nargs="?",
             action="append",
             default=["unittest.cfg", "nose2.cfg"],
-            help="Config files to load, if they exist. ('unittest.cfg' "
-            "and 'nose2.cfg' in start directory default)",
+            help=(
+                "Config files to load, if they exist. ('unittest.cfg' "
+                "and 'nose2.cfg' in start directory default)"
+            ),
         )
         self.argparse.add_argument(
             "--no-user-config",
@@ -162,8 +164,10 @@ class PluggableTestProgram(unittest.TestProgram):
             dest="load_plugins",
             const=False,
             default=True,
-            help="Do not load any plugins. Warning: nose2 does not "
-            "do anything if no plugins are loaded",
+            help=(
+                "Do not load any plugins. Warning: nose2 does not "
+                "do anything if no plugins are loaded"
+            ),
         )
         self.argparse.add_argument(
             "--plugin",
@@ -182,7 +186,7 @@ class PluggableTestProgram(unittest.TestProgram):
         self.argparse.add_argument(
             "--verbosity",
             type=int,
-            help=("Set starting verbosity level (int). " "Applies before -v and -q"),
+            help="Set starting verbosity level (int). Applies before -v and -q",
         )
         self.argparse.add_argument(
             "--verbose",
@@ -200,7 +204,7 @@ class PluggableTestProgram(unittest.TestProgram):
             action="count",
             default=0,
             dest="quiet",
-            help=("Reduce verbosity. Multiple '-q's result in " "lower verbosity."),
+            help="Reduce verbosity. Multiple '-q's result in lower verbosity.",
         )
         self.argparse.add_argument(
             "--log-level",
@@ -239,6 +243,8 @@ class PluggableTestProgram(unittest.TestProgram):
         """Find available config files"""
         filenames = cfg_args.config[:]
         proj_opts = ("unittest.cfg", "nose2.cfg")
+        if TOML_ENABLED:
+            proj_opts += ("pyproject.toml",)
         for fn in proj_opts:
             if cfg_args.top_level_directory:
                 fn = os.path.abspath(os.path.join(cfg_args.top_level_directory, fn))
@@ -302,7 +308,7 @@ class PluggableTestProgram(unittest.TestProgram):
             self.result = runner.run(self.test)
         except Exception as e:
             log.exception("Internal Error")
-            sys.stderr.write("Internal Error: runTests aborted: %s\n" % (e))
+            sys.stderr.write("Internal Error: runTests aborted: %s\n" % e)
             if self.exit:
                 sys.exit(1)
         if self.exit:
