@@ -79,7 +79,6 @@ __unittest = True
 
 
 class TestClassLoader(events.Plugin):
-
     """Loader plugin that loads test functions"""
 
     alwaysOn = True
@@ -155,7 +154,7 @@ class TestClassLoader(events.Plugin):
                         for name in names
                     ]
                 )
-            except BaseException:
+            except BaseException:  # noqa: B036
                 return event.loader.suiteClass(
                     event.loader.failedLoadTests(cls.__name__, sys.exc_info())
                 )
@@ -173,8 +172,8 @@ class TestClassLoader(events.Plugin):
             prefix = self.session.testMethodPrefix
             return (
                 attrname.startswith(prefix)
-                and hasattr(getattr(cls, attrname), "__call__")
                 and attrname not in excluded
+                and callable(getattr(cls, attrname))
             )
 
         evt = GetTestMethodNamesEvent(event.loader, cls, isTestMethod)
@@ -242,10 +241,8 @@ def MethodTestCase(cls):
 
 
 class LoadFromTestClassEvent(events.LoadFromTestCaseEvent):
-
     """Bare subclass of :class:`nose2.events.LoadFromTestCaseEvent`"""
 
 
 class GetTestMethodNamesEvent(events.GetTestCaseNamesEvent):
-
     """Bare subclass of :class:`nose2.events.GetTestCaseNamesEvent`"""
