@@ -2,7 +2,7 @@ from nose2 import events
 
 
 class PluginA(events.Plugin):
-    configSection = 'a'
+    configSection = "a"
 
     def __init__(self):
-        self.a = self.config.as_int('a', 0)
+        self.a = self.config.as_int("a", 0)
