@@ -12,4 +12,6 @@ def tearDownModule():
 
 def test(p):
     assert THINGS, "setup didn't run I think"
-test.paramList = (1,)
+
+
+test.paramList = (1,)  # type: ignore[attr-defined]
